@@ -95,12 +95,14 @@ TOP = 'top'
 POD_NOT_SPECIFIED = 'not_specified_pod'
 PROFILE_REGION = 'region'
 PROFILE_DEVICE = 'device'
+PROFILE_STATUS = 'status'
 PROFILE_HOST = 'host'
 PROFILE_AGENT_TYPE = 'type'
 PROFILE_TUNNEL_IP = 'tunnel_ip'
 PROFILE_FORCE_UP = 'force_up'
 PROFILE_LOCAL_TRUNK_ID = 'local_trunk_id'
 DEVICE_OWNER_SHADOW = 'compute:shadow'
+DEVICE_OWNER_NOVA = 'compute:nova'
 DEVICE_OWNER_SUBPORT = 'trunk:subport'
 
 # job type
